@@ -40,26 +40,26 @@ test_that("downloadData downloads and unzips module data", {
       stringsAsFactors = FALSE
     )
 
-    t1 <- system.time(downloadData(m, tmpdir, quiet = FALSE, urls = expectsInputs$sourceURL,
-                                   files = c("DEM.tif", "habitatQuality.tif")))
+    a <- capture.output(t1 <- system.time(downloadData(m, tmpdir, quiet = FALSE, urls = expectsInputs$sourceURL,
+                                   files = c("DEM.tif", "habitatQuality.tif"))))
     result <- checksums(m, tmpdir)$result
     expect_true(all(file.exists(file.path(datadir, filenames))))
     expect_true(all(result == "OK"))
 
     # shouldn't need a redownload because file exists
-    t2 <- system.time(downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL,
-                                   files = c("DEM.tif", "habitatQuality.tif")))
+    a <- capture.output(t2 <- system.time(downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL,
+                                   files = c("DEM.tif", "habitatQuality.tif"))))
     expect_true(t1[3] > t2[3]) # compare elapsed times
 
     # if one file is missing, will fill in correctly
     unlink(file.path(datadir, filenames)[1])
-    downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL)
+    a <- capture.output(downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL))
     expect_true(all(file.exists(file.path(datadir, filenames))))
 
     # if files are there, but one is incorrectly named
     file.rename(from = file.path(datadir, filenames[1]),
                 to = file.path(datadir, "test.tif"))
-    downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL) # renames the file back to expected
+    a <- capture.output(downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL)) # renames the file back to expected
     expect_true(all(file.exists(file.path(datadir, filenames))))
 
     # if files are there with correct names, but wrong content
@@ -71,9 +71,9 @@ test_that("downloadData downloads and unzips module data", {
       writeRaster(ras, filename = file.path(datadir, filenames[2]), overwrite = TRUE)
       # It updates it to new file -- but it doesn't do this correctly -- it downloads both
       #   because it doesn't know what targetFile is
-      expect_error(dwnload <- downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL))
+      a <- capture.output(expect_error(dwnload <- downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL)))
       expect_false(exists("dwnload", inherits = FALSE))
-      dwnload <- downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL, overwrite = TRUE, purge = 7)
+      a <- capture.output(dwnload <- downloadData(m, tmpdir, quiet = TRUE, urls = expectsInputs$sourceURL, overwrite = TRUE, purge = 7))
       expect_true(all(dwnload$result %in% "OK"))
       expect_true(all(file.exists(file.path(datadir, filenames))))
     }
