@@ -32,8 +32,6 @@ test_that("simList object initializes correctly", {
   expect_true(length(reqdPkgs(mySim)) == 3)
   expect_true(NROW(reqdPkgs(mySim, "fireSpread")) == 4)
 
-
-  #
   expect_is(mySim, "simList")
 
   w <- getOption("width")
@@ -50,8 +48,7 @@ test_that("simList object initializes correctly", {
   ### SLOT .xData
   expect_is(envir(mySim), "environment")
   expect_is(objs(mySim), "list")
-  expect_equal(sort(names(objs(mySim, all.names = TRUE))),
-               sort(names(as(mySim, "simList_"))))
+  expect_equal(sort(names(objs(mySim, all.names = TRUE))), sort(names(as(mySim, "simList_"))))
   expect_equivalent(mySim, as(as(mySim, "simList_"), "simList"))
   expect_equal(ls(mySim), objects(mySim))
   expect_equal(ls(mySim), sort(names(objs(mySim))))
@@ -286,32 +283,88 @@ test_that("simList test all signatures", {
 
     # needs paths and params; many defaults are fine
     expect_equal(sum(successes, na.rm = TRUE), 256)
-
   }
 })
 
-
-
 test_that("simList object initializes correctly", {
   testInitOut <- testInit("raster")
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
   ## test with outputs
-  ras = raster::raster(nrows = 10, ncols = 10, xmn = -5, xmx = 5, ymn = -5, ymx = 5)
+  ras <- raster::raster(nrows = 10, ncols = 10, xmn = -5, xmx = 5, ymn = -5, ymx = 5)
   abundRasters <- list(SpaDES.tools::gaussMap(ras, scale = 100, var = 0.01))
 
   tmpdir <- tempdir()
   newModule(name = "test", path = file.path(tmpdir, "modules"), open = FALSE)
-  obj = list(abundRasters = abundRasters)#,
-             #tempRasters = tempRasters)
-  paths = list(modulePath = file.path(tmpdir, "modules"))
-  #If start is set to 1.0, there is a warning message and spades doesn???t seem to run.
-  aa <- (capture_warnings(mySim <- simInit(times = list(start = 1.0, end = 2.0),
-                   modules = list("test"), paths = paths,
-                   objects = obj)))
+  obj <- list(abundRasters = abundRasters)#, tempRasters = tempRasters)
+  paths <- list(modulePath = file.path(tmpdir, "modules"))
+
+  ## If start is set to 1.0, there is a warning message and spades doesn't seem to run
+  aa <- (capture_warnings({
+    mySim <- simInit(times = list(start = 1.0, end = 2.0),
+                     modules = list("test"), paths = paths,
+                     objects = obj)
+    }))
   expect_length(aa, 0)
-
-
 })
 
+test_that("childModule bug test -- created infinite loop of 'Duplicated...'", {
+  ## Test resulting from bug found by Greg Paradis April 7, 2019
+  testInitOut <- testInit("raster")
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
+  setPaths(modulePath = tmpdir)
+  childModName <- "child_module"
+  newModule(childModName, tmpdir, type = "child")
+  newModule("parent_module", tmpdir, type = "parent", children = c("child_module"))
+  paths <- getPaths()
+  modules <- list("parent_module")
+  times <- list(start = 1, end = 10)
+  expect_is({mySim <- simInit(paths = paths, modules = modules, times = times)}, "simList")
+  ## test some child related stuff
+  expect_true(all(modules(mySim) %in% childModName))
+  expect_true(dirname(names(modules(mySim))) %in% modulePath(mySim))
+})
+
+test_that("test that module directory exists, but not files", {
+  ## Test resulting from bug found by Eliot McIntire April 28, 2019
+  testInitOut <- testInit("raster")
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
+  setPaths(modulePath = tmpdir)
+  childModName <- "child_module"
+  parentModName <- "parent_module"
+  newModule(childModName, tmpdir, type = "child", open = FALSE)
+  newModule(parentModName, tmpdir, type = "parent", children = childModName, open = FALSE)
+  paths <- getPaths()
+  modules <- list(parentModName)
+  times <- list(start = 1, end = 10)
+  mainChildModuleFile <- file.path(paths$modulePath, childModName, paste0(childModName, ".R") )
+  mainParentModuleFile <- file.path(paths$modulePath, parentModName, paste0(parentModName, ".R") )
+  expect_true(file.exists(mainChildModuleFile))
+
+  file.remove(mainChildModuleFile)
+  a <- capture_messages({
+    expect_error(simInit(paths = paths, modules = modules, times = times), "does not exist")
+  })
+
+  unlink(dirname(mainChildModuleFile), recursive = TRUE)
+  a <- capture_messages({
+    expect_error(simInit(paths = paths, modules = modules, times = times), "does not exist")
+  })
+
+  file.remove(mainParentModuleFile)
+  a <- capture_messages({
+    expect_error(simInit(paths = paths, modules = modules, times = times), "are missing")
+  })
+
+  unlink(dirname(mainParentModuleFile), recursive = TRUE)
+  a <- capture_messages({
+    expect_error(simInit(paths = paths, modules = modules, times = times), "doesn't exist in")
+  })
+
+  unlink(paths$modulePath, recursive = TRUE)
+})
